@@ -1,10 +1,10 @@
 /*
  * Program name:  equake
- * Version:	  1.03.6
+ * Version:	  1.03.7
  * Source file:	  equake_processdata.c
  * Description:	  Equake pulls data about earthquakes and displays it in interesting ways
  *
- * Copyright (C) 2012-2014 Jeroen van Aart
+ * Copyright (C) 2012-2015 Jeroen van Aart
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -207,6 +207,15 @@ int processdata_daily(struct Equake_Data *equakedata)
                               if (equakedata->equakeformatday[n].region=="")
                                 return -1;
 
+                              /*
+                               * we test whether running is NULL to fix a rare and random bug
+                               * occasionally, especially with limited bandwidth and/or congested network connectivity, 
+                               * the last bit of the data would be cut off and the last quotation mark of the place CSV field 
+                               * could be missing, running would as result be NULL and if we don't test for it here it will crash strchr()
+                               */
+                              if(running==NULL)
+                                break;
+
                               /* 
                                * we find a newline and then try to go one step after that which is the start of the
                                * next line, or if that fails we reached the end of the buffer
@@ -398,6 +407,15 @@ int processdata_weekly(struct Equake_Data *equakedata)
                               if (equakedata->equakeformatweek[n].region=="")
                                 return -1;
 
+                              /*
+                               * we test whether running is NULL to fix a rare and random bug
+                               * occasionally, especially with limited bandwidth and/or congested network connectivity, 
+                               * the last bit of the data would be cut off and the last quotation mark of the place CSV field 
+                               * could be missing, running would as result be NULL and if we don't test for it here it will crash strchr()
+                               */
+                              if(running==NULL)
+                                break;
+
                               /* 
                                * we find a newline and then try to go one step after that which is the start of the
                                * next line, or if that fails we reached the end of the buffer
@@ -743,6 +761,15 @@ int processdata(struct Equake_Data *equakedata, int period)
                               if (equakedata->equakeformat[n].region=="")
                                 return -1;
 
+                              /*
+                               * we test whether running is NULL to fix a rare and random bug
+                               * occasionally, especially with limited bandwidth and/or congested network connectivity, 
+                               * the last bit of the data would be cut off and the last quotation mark of the place CSV field 
+                               * could be missing, running would as result be NULL and if we don't test for it here it will crash strchr()
+                               */
+                              if(running==NULL)
+                                break;
+
                               /* 
                                * we find a newline and then try to go one step after that which is the start of the
                                * next line, or if that fails we reached the end of the buffer
